@@ -298,7 +298,7 @@ flatten_query <- function(op, ops=list())
     if (is_empty(ops))
         new_ops <- list(flat_op)
     else
-        new_ops <- prepend(ops, list(flat_op))
+        new_ops <- c(list(flat_op), ops)
     if (inherits(op, "op_base"))
         return(new_ops)
     else
@@ -347,7 +347,7 @@ kql_query <- function(ops, src)
     )
 }
 
-build_by_clause <- function(x, y )
+build_by_clause <- function(x, y)
 {
     sprintf("$left.%s == $right.%s", escape(ident(x)), escape(ident(y)))
 }
